@@ -55,8 +55,12 @@ class Manager(object):
         """Finds rows that meet ``values`` with comparison ``operation``
         in given ``db`` and ``table``.
 
-        Returns a list of pairs. First item in pair is field name, second is
-        its value.
+        Returns a list of lists of pairs. First item in pair is field name,
+        second is its value.
+        For example, if two rows with two columns each are returned::
+        
+          [[('field', 'first_row_value'), ('otherfield', 'first_row_othervalue')],
+           [('field', 'second_row_value'), ('otherfield', 'second_row_othervalue')]]
 
         :param string db: database name
         :param string table: table name
@@ -74,7 +78,7 @@ class Manager(object):
             In case multiple rows are expected to be returned, ``limit`` must be
             set explicitly, HS wont get all found rows by default.
         :param integer offset: optional offset of rows to search for.
-        :rtype: list of tuples
+        :rtype: list of lists of tuples
         """
         index_id = self.read_socket.get_index_id(db, table, fields, index_name)
         data = self.read_socket.find(index_id, operation, values, limit, offset)
@@ -136,8 +140,11 @@ class Manager(object):
         data = self.write_socket.find_modify(index_id, operation, values, op,
                                              update_values, limit, offset)
 
-        return return_original and data or int(data[0])
-
+        if data:
+            data = return_original and [zip(fields, row) for row in data] \
+                or int(data[0])
+        return data
+    
     @retry_on_failure
     def incr(self, db, table, operation, fields, values, step=['1'], index_name=None,
                limit=0, offset=0, return_original=False):
@@ -172,7 +179,10 @@ class Manager(object):
         data = self.write_socket.find_modify(index_id, operation, values, op,
                                              step, limit, offset)
 
-        return return_original and data or int(data[0])
+        if data:
+            data = return_original and [zip(fields, row) for row in data] \
+                or int(data[0])
+        return data
 
     @retry_on_failure
     def decr(self, db, table, operation, fields, values, step=['1'], index_name=None,
@@ -208,7 +218,10 @@ class Manager(object):
         data = self.write_socket.find_modify(index_id, operation, values, op,
                                              step, limit, offset)
 
-        return return_original and data or int(data[0])
+        if data:
+            data = return_original and [zip(fields, row) for row in data] \
+                or int(data[0])
+        return data
 
     @retry_on_failure
     def delete(self, db, table, operation, fields, values, index_name=None,
@@ -242,7 +255,10 @@ class Manager(object):
         data = self.write_socket.find_modify(index_id, operation, values, op,
                                              limit=limit, offset=offset)
 
-        return return_original and data or int(data[0])
+        if data:
+            data = return_original and [zip(fields, row) for row in data] \
+                or int(data[0])
+        return data
 
     def purge(self):
         """Purges all read and write connections.
