@@ -287,9 +287,10 @@ class HandlerSocket(threading.local):
             raise OperationalError('HandlerSocket returned an error code: %s' % error)
 
         columns = int(tokens[1])
-        decoded_tokens = imap(decode, tokens[2:])
+        data_tokens = tokens[2:]
+        decoded_tokens = imap(decode, data_tokens)
         # Divide response tokens list by number of columns
-        if columns > 1:
+        if len(data_tokens) > 1:
             data = zip(*[decoded_tokens]*columns)
         else:
             data = list(decoded_tokens)
